# Digit Index

This package contains an effective algorithm for finding what
digit is placed on certain 0-based or 1-based index in string
of numbers from zero to infinity

# Install
    pip install digit-index
   
# Usage

    import digit_index
    
    digit = digit_index.get_digit_zero_based(0)
    print(digit) # 0
    
    digit = digit_index.get_digit_one_based(0)
    print(digit) # 1
    
# License

MIT